/*
 * Copyright (c) 2015 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 /*global
    setMemoCount, pageHandler, getUpdateMemo, setMemoContent, setBookContent: false,
    memo_id: true
 */

var db;

function deleteTable() {
    db.transaction(function (tx) {
        tx.executeSql("DROP TABLE memo", []);
    });
}

function createTable() {
    db.transaction(function (tx) {
        tx.executeSql("CREATE TABLE IF NOT EXISTS memo (id INTEGER PRIMARY KEY AUTOINCREMENT," +
            " subject, text, book, date, image)", []);
    });

    db.transaction(function (tx) {
        tx.executeSql("CREATE TABLE IF NOT EXISTS book (book)", []);
    });
}

function updateMemoTable(id, subject, body, book, date, image) {
    db.transaction(function (tx) {
        tx.executeSql("UPDATE memo SET subject=?, text=?, book=?, date=?, image=? where id=?",
            [subject, body, book, date, image, id] );
    });

}

function insertMemoTable(subject, body, book, date, image) {
    db.transaction(function (tx) {
        tx.executeSql("INSERT INTO memo VALUES(NULL,?,?,?,?,?)", [subject, body, book, date, image] );
    });
}

function insertBookTable() {
    var input_book = document.querySelector('#input_book'),
        book;

    book = input_book.value;
    db.transaction(function (tx) {
        tx.executeSql("INSERT INTO book VALUES(?)", [book] );
    });
}

function getSelectMemoCount() {
    var notebook = document.querySelector('#header_button').innerHTML,
        count;

    db.transaction(function (tx) {
        tx.executeSql("SELECT * FROM memo WHERE book=?", [notebook],
            function(tx,result) {
                count = result.rows.length;
                setMemoCount(count);
        });
    });
}

function deleteMemo() {
    db.transaction(function (tx) {
        tx.executeSql("DELETE FROM memo WHERE id=?", [memo_id],
            function() {
                pageHandler("main");
                memo_id = null;
        });
    });
}

function getSelectIdMemo(id) {
    var i,
        row;

    db.transaction(function (tx) {
        tx.executeSql("SELECT * FROM memo WHERE id=?", [id],
            function(tx, result) {
                for (i=0; i<result.rows.length; i++) {
                    row = result.rows.item(i);
                    getUpdateMemo(row['subject'], row['text'], row['image']);
                }
        });
    });
}

function getSelectMemoContent() {
    var memo = document.querySelector('#main'),
        notebook = document.querySelector('#header_button').innerHTML,
        i,
        row;

    memo.innerHTML = '';
    db.transaction(function (tx) {
        tx.executeSql("SELECT * FROM memo WHERE book=?", [notebook],
            function(tx, result) {
                for (i=0; i<result.rows.length; i++) {
                    row = result.rows.item(i);
                    setMemoContent(row['id'], row['subject'], row['text'], row['date'], row['image']);
                }
        });
    });
}

function getSelectBook() {
    var memo = document.querySelector('#main_book'),
        book,
        i,
        row;

    memo.innerHTML = '';
    setBookContent("default");
    db.transaction(function (tx) {
        tx.executeSql("SELECT DISTINCT book FROM book", [],
            function(tx,result) {
                for (i=0; i<result.rows.length; i++) {
                    row = result.rows.item(i);
                    book = row['book'];
                    setBookContent(book);
                }
        });
    });
}


function openDB() {
    if (window.openDatabase) {
        db = window.openDatabase("myMemoDB", "1.0", "for memo sample webapp", 1024*1024);
    } else {
        console.warn("not web sql support");
    }
    createTable();
}